@@ -1,10 +1,12 @@
 #define _LARGEFILE64_SOURCE     /* required for GLIBC to enable stat64 and friends */
-#include <sys/types.h>
 #include <regex.h>
-#include <sys/stat.h>
+#include <string.h>
+#include <time.h>
 #include <unistd.h>
-#include <sys/socket.h>
 #include <netinet/in.h>
+#include <sys/socket.h>
+#include <sys/stat.h>
+#include <sys/types.h>
 
 #include "mt.h"
 #include "mem.h"
@@ -31,7 +33,7 @@ const char *F1 = "For help at any time press F1.";
 int *n_win_per_col = NULL;
 int *vertical_split = NULL;
 color_scheme *cschemes = NULL;
-const char *version_str = " --*- multitail " VERSION " (C) 2003-2007 by folkert@vanheusden.com -*--";
+const char *version_str = " --*- multitail " VERSION " (C) 2003-2013 by folkert@vanheusden.com -*--";
 conversion *conversions = NULL;
 keybinding *keybindings = NULL;
 pars_per_file *ppf = NULL;
@@ -47,7 +49,7 @@ char *global_find = NULL;
 int terminal_main_index = -1;
 int default_color_scheme = -1;
 int max_y, max_x;
-int min_n_bufferlines = 25;
+int min_n_bufferlines = -1;
 int mode_statusline = 1;
 int n_children = 0;
 int n_conversions = 0;
@@ -160,3 +162,13 @@ char *sigs[] = { NULL, "SIGHUP", "SIGINT", "SIGQUIT", "SIGILL", "SIGTRAP", "SIGA
 int n_known_sigs = 32;
 char *severities[8] = { "emerg", "alert", "crit", "err", "warning", "notice", "info", "debug" };
 char *facilities[24] = { "kern", "user", "mail", "daemon", "auth", "syslog", "lpr", "news", "uucp", "cron", "authpriv", "ftp", "?", "?", "?", "?", "local0", "local1", "local2", "local3", "local4", "local5", "local6", "local7" };
+
+void set_do_refresh(char val)
+{
+	do_refresh = val;
+}
+
+char get_do_refresh()
+{
+	return do_refresh;
+}
