@@ -104,7 +104,7 @@ char *help_add_file_or_cmd[] = {
 char *help_list_keybindings[] = {
 		"This screen lists the keybindings you defined in",
 		"the MultiTail configurationfile which is located",
-		"in /etc/multitail.conf. The keybindings only",
+		"in "CONFIG_FILE". The keybindings only",
 		"work in the main screen.",
 		"In this screen, you can press the followking",
 		"keys:",
