@@ -37,6 +37,10 @@
 #include <netinet/in.h>
 #include <arpa/inet.h>
 #include <netdb.h>
+#ifdef UTF8_SUPPORT
+#include <wchar.h>
+#include <wctype.h>
+#endif
 
 #include "mt.h"
 #include "globals.h"
@@ -385,16 +389,7 @@ void signal_handler(int sig)
 
 void select_display_start_and_end(char *string, char mode, int wrap_offset, int win_width, int *prt_start, int *prt_end, int *disp_end)
 {
-	/* patch by Thomas Gartner */
-	int nbytes = 0; /* = strlen(string); */
-	char *tmpString=string;
-	while(string && *tmpString)
-	{
-		if (*tmpString++==9)
-			nbytes += tab_width;
-		else
-			++nbytes;
-	}
+	int nbytes = strlen(string);
 
 	*prt_start = 0;
 	*prt_end = nbytes;
@@ -447,13 +442,8 @@ int draw_tab(NEWWIN *win)
 {
 	if (tab_width)
 	{
-		int cury, curx, move, loop;
-
-		/* get current coordinate */
-		getyx(win -> win, cury, curx);
-
-		/* calculate new coordinate */
-		move = (((curx / tab_width) + 1) * tab_width) - curx;
+		int curx = getcurx(win -> win), loop;
+		int move = (((curx / tab_width) + 1) * tab_width) - curx;
 
 		for(loop=0; loop<move; loop++)
 			waddch(win -> win, ' ');
@@ -586,11 +576,22 @@ void gen_wordwrap_offsets(char *string, int start_offset, int end_offset, int wi
 	(*offsets)[n_ww] = -1;
 }
 
+int count_utf_bytes(int c)
+{
+        if ((c & 0xe0) == 0xc0)
+                return 2;
+        else if ((c & 0xf0) == 0xe0)
+                return 3;
+        else if ((c & 0xf8) == 0xf0)
+                return 4;
+
+        return 1;
+}
+
 void do_color_print(proginfo *cur, char *use_string, int prt_start, int prt_end, int disp_end, color_offset_in_line *cmatches, int n_cmatches, mybool_t has_merge_colors, char start_reverse, regmatch_t *matches, int matching_regex, char use_regex, NEWWIN *win)
 {
 	int offset;
 	myattr_t cdev = { -1, -1 };
-	char reverse = start_reverse;
 	char default_reverse_state = 0;
 	int disp_offset = 0;
 	char highlight_part = toupper(use_regex) == 'C';
@@ -610,20 +611,35 @@ void do_color_print(proginfo *cur, char *use_string, int prt_start, int prt_end,
 	}
 
 	/* print text */
-	for(offset=prt_start; offset<prt_end; offset++)
+	for(offset=prt_start; offset<prt_end;)
 	{
 		char re_inv = default_reverse_state;
 		char is_control_or_extended_ascii = 0;
-		unsigned char current_char = (unsigned char)use_string[offset];
 		myattr_t new_cdev = { -1, -1 };
 
+#ifdef UTF8_SUPPORT
+		const char *dummy = &use_string[offset];
+		wchar_t wcur = 0;
+		mbsrtowcs(&wcur, &dummy, 1, NULL);
+#else
+		char wcur = use_string[offset];
+#endif
+
 		if (ww != NULL && offset == ww[ww_offset])
 		{
 			wprintw(win -> win, "\n");
 			ww_offset++;
 
-			if (isspace(use_string[offset]))
+#ifdef UTF8_SUPPORT
+			if (iswspace(wcur))
+#else
+			if (isspace(wcur))
+#endif
+			{
+				offset++;
+
 				continue;
+			}
 		}
 
 		/* find things to colorize */
@@ -647,21 +663,25 @@ void do_color_print(proginfo *cur, char *use_string, int prt_start, int prt_end,
 		}
 
 		/* control-characters will be displayed as an inverse '.' */
-		if (current_char < 32 || current_char == 127 || (current_char > 127 && !allow_8bit))
+#ifdef UTF8_SUPPORT
+		if (iswcntrl(wcur))
+#else
+		if (iscntrl(wcur))
+#endif
 		{
 			is_control_or_extended_ascii = 1;
 
-			if (current_char != 13 && current_char != 9)
+#ifdef UTF8_SUPPORT
+			if (!iswspace(wcur))
+#else
+			if (!isspace(wcur))
+#endif
 				re_inv = 1;
 		}
 
 		if (re_inv)
-		{
 			new_cdev.attrs = inverse_attrs;
 
-			reverse = 1;
-		}
-
 		/* new color selected? then switch off previous color */
 		if (cdev.colorpair_index != new_cdev.colorpair_index || cdev.attrs != new_cdev.attrs)
 		{
@@ -669,43 +689,46 @@ void do_color_print(proginfo *cur, char *use_string, int prt_start, int prt_end,
 
 			myattr_on(win, new_cdev);
 
-			reverse = new_cdev.attrs != -1 && new_cdev.attrs & A_REVERSE;
-
 			cdev = new_cdev;
 		}
 
 		if (!is_control_or_extended_ascii)
 		{
-			waddch(win -> win, (const chtype)current_char);
+#ifdef UTF8_SUPPORT
+			waddnwstr(win -> win, &wcur, 1);
+#else
+			wprintw(win -> win, "%c", wcur);
+#endif
+
 			disp_offset++;
 		}
 		else
 		{
-			if (current_char > 126)
-			{
-				waddch(win -> win, '.');
-				disp_offset++;
-			}
-			else if (current_char == 9 && tab_width > 0)	/* TAB? */
+			/* error_exit("> 126 %d: %02x %02x %02x", wcur, use_string[offset+0],  use_string[offset+1], use_string[offset+2]); */
+
+			if (wcur == 9 && tab_width > 0)	/* TAB? */
 			{
 				disp_offset += draw_tab(win);
 			}
 			/* 13 (CR) is just silently ignored */
-			else if (current_char != 13)
+			else if (wcur != 13)
 			{
 				if (caret_notation)
 				{
-					wprintw(win -> win, "^%c", 'a' + current_char - 1);
+					wprintw(win -> win, "^%c", 'a' + wcur - 1);
 					disp_offset++;
 				}
 				else
 					waddch(win -> win, '.');
+
 				disp_offset++;
 			}
 		}
 
 		if (disp_offset >= disp_end && disp_end != -1)
 			break;
+
+		offset += count_utf_bytes(use_string[offset]);
 	}
 
 	if (prt_start == prt_end)       /* scrolled out line */
@@ -728,7 +751,7 @@ void color_print(int f_index, NEWWIN *win, proginfo *cur, char *string, regmatch
 	int n_cmatches = 0;
 	mybool_t has_merge_colors = MY_FALSE;
 	char *use_string = NULL;
-	int y, x;
+	int x;
 
 	/* stop if there's no window tou output too */
 	if (!win)
@@ -740,7 +763,7 @@ void color_print(int f_index, NEWWIN *win, proginfo *cur, char *string, regmatch
 	 * to the left itself when emitting text)
 	 */
 	mx = getmaxx(win -> win);
-	getyx(win -> win, y, x);
+	x = getcurx(win -> win);
 	if ((x != 0 && x != mx) || !suppress_empty_lines)
 		wprintw(win -> win, "\n");
 
@@ -1321,7 +1344,7 @@ void update_statusline(NEWWIN *status, int win_nr, proginfo *cur)
 {
 	if (mode_statusline > 0 && status != NULL && cur != NULL)
 	{
-		int dx, dy;
+		int dx;
 		myattr_t attrs = statusline_attrs;
 		int statusline_len = 0;
 		off64_t	fsize = (off64_t)-1;
@@ -1367,7 +1390,7 @@ void update_statusline(NEWWIN *status, int win_nr, proginfo *cur)
 		else if (mail)
 			wprintw(status -> win, " You've got mail!");
 
-		getmaxyx(status -> win, dy, dx);
+		dx = getcurx(status -> win);
 		if (dx >= (statusline_len + 13))
 		{
 			if (cur -> paused)
@@ -1466,7 +1489,6 @@ void create_window_set(int startx, int width, int nwindows, int indexoffset)
 	int loop;
 
 	int term_offset = 0;
-	int last_not_hidden_window = -1;
 	int n_not_hidden = 0;
 	int n_height_not_set = 0;
 	int n_lines_requested = 0, n_with_nlines_request = 0;
@@ -1483,16 +1505,19 @@ void create_window_set(int startx, int width, int nwindows, int indexoffset)
 	for(loop=0; loop<nwindows; loop++)
 	{
 		int cur_win_index = loop + indexoffset;
-		if (cur_win_index >= nfd) break;
+
+		if (cur_win_index >= nfd)
+			break;
 
 		if (pi[cur_win_index].hidden == 0)
-		{
-			last_not_hidden_window = loop;
 			n_not_hidden++;
-		}
 	}
+
 	if (n_not_hidden == 0)
+	{
+		free(lines_per_win);
 		return;
+	}
 
 	/* count the number of lines needed by the windows for which
 	 * the height is explicitly set
@@ -1882,7 +1907,7 @@ void do_set_bufferstart(int f_index, char store_what_lines, int maxnlines)
 	lb[f_index].maxnlines = maxnlines;
 }
 
-char close_window(int winnr, proginfo *cur)
+char close_window(int winnr, proginfo *cur, mybool_t stop_proc)
 {
 	if (winnr == terminal_main_index)
 	{
@@ -1891,7 +1916,8 @@ char close_window(int winnr, proginfo *cur)
 	}
 
 	/* make sure it is really gone */
-	stop_process(cur -> pid);
+	if (stop_proc)
+		stop_process(cur -> pid);
 
 	/* restart window? */
 	if (cur -> restart.restart >= 0)
@@ -2694,6 +2720,9 @@ int main(int argc, char *argv[])
 	char *dummy = getenv("MAILCHECK");
 	struct servent *sl = getservbyname("syslog", "tcp");
 
+	/* for mbsrtowcs */
+	setlocale(LC_CTYPE, "");
+
 	if (sl)
 		syslog_port = sl -> s_port;
 
@@ -2874,7 +2903,7 @@ int check_for_died_processes(void)
 				/* did it exit? */
 				if (died_proc == cur -> pid && cur -> wt != WT_STDIN && cur -> wt != WT_SOCKET)
 				{
-					int refresh_info = close_window(f_index, cur);
+					int refresh_info = close_window(f_index, cur, MY_FALSE);
 
 					found = a_window_got_closed = 1;
 
@@ -3263,7 +3292,6 @@ int recv_from_fd(int fd, char **buffer, int new_data_offset, int read_size)
 	socklen_t ssa_len = sizeof(sa);
 	char *recv_buffer = mymalloc(read_size + 1);
 	char time_buffer[TIMESTAMP_EXTEND_BUFFER];
-	int time_len;
 	char *host = "";
 	char *facility = "";
 	char *severity = "";
@@ -3271,7 +3299,6 @@ int recv_from_fd(int fd, char **buffer, int new_data_offset, int read_size)
 	int nbytes;
 
 	get_now_ts(syslog_ts_format, time_buffer, sizeof(time_buffer));
-	time_len = strlen(time_buffer);
 
 	nbytes = recvfrom(fd, recv_buffer, read_size, 0, &sa, &ssa_len);
 	recv_buffer[nbytes] = 0x00;
@@ -3293,10 +3320,10 @@ int recv_from_fd(int fd, char **buffer, int new_data_offset, int read_size)
 
 	if (show_severity_facility == MY_TRUE)
 	{
-		if (recv_buffer[0] == '<' &&
-				(recv_buffer[2] == '>' || recv_buffer[3] == '>' || recv_buffer[4] == '>'))
+		char *gt = strchr(recv_buffer, '>');
+
+		if (recv_buffer[0] == '<' && (recv_buffer[2] == '>' || recv_buffer[3] == '>' || recv_buffer[4] == '>') && gt != NULL)
 		{
-			char *gt = strchr(recv_buffer, '>');
 			int value = atoi(recv_buffer + 1);
 			int severity_nr = value & 7;
 			int facility_nr = value / 8;
@@ -3513,11 +3540,12 @@ int wait_for_keypress(int what_help, double max_wait, NEWWIN *popup, char cursor
 								if (last_changed_window == cur)
 									last_changed_window = NULL;
 
-								deleted_entry_in_array = close_window(loop, cur);
+								deleted_entry_in_array = close_window(loop, cur, MY_TRUE);
 
 								if (deleted_entry_in_array >= 0)
 								{
 									set_do_refresh(2);
+									free(buffer);
 									goto closed_window;
 								}
 								else if (cur -> restart.do_diff && get_do_refresh() == 0)
@@ -3550,7 +3578,7 @@ int wait_for_keypress(int what_help, double max_wait, NEWWIN *popup, char cursor
 						if (last_changed_window == cur)
 							last_changed_window = NULL;
 
-						deleted_entry_in_array = close_window(loop, cur);
+						deleted_entry_in_array = close_window(loop, cur, MY_TRUE);
 						if (deleted_entry_in_array >= 0)
 						{
 							set_do_refresh(2);
