@@ -48,12 +48,17 @@ typedef enum { SCHEME_TYPE_EDIT = 0, SCHEME_TYPE_FILTER } filter_edit_scheme_t;
 #define __USE_BSD	/* manpage says _BSD_SOURCE, stdlib.h says __USE_BSD */
 #endif
 
-#if defined(sun) || defined(__sun) || defined(scoos) || defined(_HPUX_SOURCE) || defined(AIX) || defined(__CYGWIN__) || defined(__minix)
-	#include <ncurses/panel.h>
-	#include <ncurses/ncurses.h>
+#ifdef UTF8_SUPPORT
+	#include <ncursesw/panel.h>
+	#include <ncursesw/ncurses.h>
 #else
-	#include <panel.h>
-	#include <ncurses.h>
+	#if defined(sun) || defined(__sun) || defined(scoos) || defined(_HPUX_SOURCE) || defined(AIX) || defined(__CYGWIN__)
+		#include <ncurses/panel.h>
+		#include <ncurses/ncurses.h>
+	#else
+		#include <panel.h>
+		#include <ncurses.h>
+	#endif
 #endif
 
 /* it seems the default HP-UX c-compiler doesn't understand atoll and
