@@ -1,3 +1,4 @@
+#define _LARGEFILE64_SOURCE     /* required for GLIBC to enable stat64 and friends */
 /* I read somewhere that this is needed on HP-UX */
 #define _INCLUDE_HPUX_SOURCE
 #define _INCLUDE_POSIX_SOURCE
@@ -16,6 +17,8 @@
 #include <unistd.h>
 #include <fcntl.h>
 
+#include <netinet/in.h>
+
 #include <sys/ioctl.h>
 
 #include "mt.h"
@@ -26,13 +29,13 @@
 #ifdef __OpenBSD__
 #include <util.h>
 #endif
-#if defined(linux) || defined(__CYGWIN__)
+#if defined(linux) || defined(__CYGWIN__) || defined(__GNU__) || defined(__GLIBC__)
 #include <pty.h>
 #endif
-#ifdef __FreeBSD__
+#if defined(__FreeBSD__) || defined(__minix)
 #include <libutil.h>
 #endif
-#ifdef sun
+#if defined(sun) || defined(__sun)
 #include <sys/stropts.h>
 #include <stdlib.h>
 #endif
@@ -40,7 +43,7 @@
 #endif
 #if defined(AIX)
 #endif
-#if defined(hpux) || defined(__hpux)
+#if defined(_HPUX_SOURCE)
 #include <sys/stream.h>
 #include <sys/stropts.h>
 #include <sys/termios.h>
@@ -50,6 +53,7 @@
 #include <sys/strtio.h>
 #include <sys/eucioctl.h>
 #endif
+#include <sys/socket.h>
 
 #include "error.h"
 
@@ -74,17 +78,17 @@
 
 int get_pty_and_fork(int *fd_master, int *fd_slave)
 {
-#if defined(__FreeBSD__) || defined(linux) || defined(__OpenBSD__) || defined(__NetBSD__) || defined(__APPLE__) || defined(__CYGWIN__)
+#if defined(__FreeBSD__) || defined(linux) || defined(__OpenBSD__) || defined(__NetBSD__) || defined(__APPLE__) || defined(__CYGWIN__) || defined(__GNU__) || defined(__GLIBC__) || defined(__minix)
 
 	if (openpty(fd_master, fd_slave, NULL, NULL, NULL) == -1)
 	{
-		error_exit("openpty failed\n");
+		error_exit("openpty() failed.\n");
 		return -1;
 	}
 
 	return fork();
 
-#elif defined(sun) || defined(AIX) || defined(hpux) || defined(__hpux) || defined(OSF1)
+#elif defined(sun) || defined(__sun) || defined(AIX) || defined(_HPUX_SOURCE) || defined(OSF1) || defined(scoos)
 
 	/*
 	 * This code is used e.g. on Solaris 2.x.  (Note that Solaris 2.3
@@ -101,7 +105,7 @@ int get_pty_and_fork(int *fd_master, int *fd_slave)
 
 	ptm = myopen(multiplexer, O_RDWR | O_NOCTTY);
 	if (ptm < 0) {
-		error_exit("error opening %s", multiplexer);
+		error_exit("Error opening %s.\n", multiplexer);
 		return -1;
 	}
 	*fd_master = ptm;
@@ -109,20 +113,20 @@ int get_pty_and_fork(int *fd_master, int *fd_slave)
 	pid = fork();
 	if (pid == 0)
 	{
-		if (grantpt(ptm) < 0) error_exit("grantpt failed");
-		if (unlockpt(ptm) < 0) error_exit("unlockpt failed");
+		if (grantpt(ptm) < 0) error_exit("grantpt() failed.\n");
+		if (unlockpt(ptm) < 0) error_exit("unlockpt() failed.\n");
 		setsid(); /* lose old controlling terminal (FvH) */
 		pts = ptsname(ptm);
-		if (pts == NULL) error_exit("Slave pty side name could not be obtained.");
+		if (pts == NULL) error_exit("Slave pty side name could not be obtained.\n");
 
 		/* Open the slave side. */
 		*fd_slave = myopen(pts, O_RDWR | O_NOCTTY);
-		if (*fd_slave < 0) error_exit("problem opening slave-side of pseudo tty (%s)", pts);
+		if (*fd_slave < 0) error_exit("Problem opening slave-side of pseudo tty (file '%s').\n", pts);
 
-#ifndef AIX
+#if !defined(AIX) && !defined(scoos)
 		/* Push the appropriate streams modules, as described in Solaris pts(7). */
-		if (ioctl(*fd_slave, I_PUSH, "ptem") < 0) error_exit("ioctl I_PUSH ptem failed");
-		if (ioctl(*fd_slave, I_PUSH, "ldterm") < 0) error_exit("ioctl I_PUSH ldterm failed");
+		if (ioctl(*fd_slave, I_PUSH, "ptem") < 0) error_exit("ioctl I_PUSH ptem failed.\n");
+		if (ioctl(*fd_slave, I_PUSH, "ldterm") < 0) error_exit("ioctl I_PUSH ldterm failed.\n");
 		(void)ioctl(*fd_slave, I_PUSH, "ttcompat"); /* not on HP-UX? */
 #endif
 	}
@@ -132,10 +136,10 @@ int get_pty_and_fork(int *fd_master, int *fd_slave)
 #elif defined(IRIX) || defined(IRIX64)
 
 	char *line = _getpty(fd_master, O_RDWR | O_NDELAY, 0600, 0);
-	if (line == NULL) error_exit("_getpy failed\n");
+	if (line == NULL) error_exit("_getpy() failed.\n");
 
 	*fd_slave = myopen(line, O_RDWR);
-	if (*fd_slave < 0) error_exit("open(%s) failed\n", line);
+	if (*fd_slave < 0) error_exit("Error while openening file %s.\n", line);
 
 	return fork();
 
